summaryrefslogtreecommitdiff
path: root/expt_0406.cu
diff options
context:
space:
mode:
authorKunoiSayami <[email protected]>2023-06-04 19:35:54 +0800
committerKunoiSayami <[email protected]>2023-06-04 19:35:54 +0800
commit155b3a832c590c55ea3d89dd0783713f1d0f19c1 (patch)
treedfeb770865c77f76cf1ab5448f628b7e21bec483 /expt_0406.cu
parent1fbb943005ad78335f0b921be516b3df8140406d (diff)
fix: Fix compile error
Signed-off-by: KunoiSayami <[email protected]>
Diffstat (limited to 'expt_0406.cu')
-rw-r--r--expt_0406.cu5
1 files changed, 4 insertions, 1 deletions
diff --git a/expt_0406.cu b/expt_0406.cu
index 96533c9..30ee7c4 100644
--- a/expt_0406.cu
+++ b/expt_0406.cu
@@ -1,3 +1,4 @@
+#include "sortlib.cuh"
#include <algorithm>
#include <cassert>
#include <cstdio>
@@ -55,7 +56,9 @@ __global__ void kernel(unsigned long step, const double slice_size) {
auto tid = step * (blockIdx.x * blockDim.x + threadIdx.x) + i;
// printf("%d\n", tid);
- auto index = (int)(sample_cdf(cudaPopulationItem[tid]) / slice_size);
+ auto index = (int)(FactorySort::sample_cdf(cudaSampleItem, length,
+ cudaPopulationItem[tid]) /
+ slice_size);
cdf_result[index] = true;
}